@@ -1,8 +1,4 @@
 package Data::Trace;
-    #TODO: Remove this debug code !!!
-    use Kernel::Prof;
-    my $ProfilerObject = Kernel::Prof->Run( Name => 'Test', UseTriggers => 1 );
-
 
 =head1 NAME
 
@@ -24,7 +20,7 @@ use parent  qw( Exporter );
 use feature qw( say );
 
 our @EXPORT  = qw( Trace );
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 =head1 SYNOPSIS
 
